@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,17 +35,20 @@ char nutdir1[]=".nutdb";
 char nutdir1[]=NUTDIR ;
 #endif
 
-char USDAjoined1[] = "sr21.nut";
+char USDAjoined1[] = "sr22.nut";
 char globalFOOD1[] = "FOOD_DES.txt";
 char globalNUT1[] = "NUT_DATA.txt";
 char globalWEIGHT1[] = "WEIGHT.txt";
 char weightlib1[] = "WEIGHT.lib";
+char WLOG1[] = "WLOG.txt";
+char WLOGold1[] = "WLOG.old";
 char localFOOD1[] = "FOOD_DES.txt";
 char localNUT1[] = "NUT_DATA.txt";
 char localWEIGHT1[] = "WEIGHT.txt";
 char foodfile1[] = "food.db";
 char mealfile1[] = "meal.db";
 char mealexpfile1[] = "meal.exp";
+char theusualexpfile1[] = "theusual.exp";
 char theusualfile1[] = "theusual.db";
 char optionsfile1[] = "options.db";
 char localOPTIONS1[] = "OPTIONS.txt";
@@ -57,12 +60,15 @@ char globalFOOD[2000];
 char globalNUT[2000];
 char globalWEIGHT[2000];
 char weightlib[2000];
+char WLOG[2000];
+char WLOGold[2000];
 char localFOOD[2000];
 char localNUT[2000];
 char localWEIGHT[2000];
 char foodfile[2000];
 char mealfile[2000];
 char mealexpfile[2000];
+char theusualexpfile[2000];
 char theusualfile[2000];
 char optionsfile[2000];
 char localOPTIONS[2000];
@@ -873,6 +879,76 @@ if (need_to_find_next_recipe) while (food_ptr->next != NULL)
  }
 }
 
+void read_WLOG(int *n, int *fatn, int *up, float *weightslope, float *fatslope)
+{
+char buffer[101];
+float weight, bf, stardate;
+float fat;
+float sumweightx = 0, sumweighty = 0, sumweightxx = 0, sumweightxy = 0;
+float sumfatx = 0, sumfaty = 0, sumfatxx = 0, sumfatxy = 0; 
+
+*n = 0;
+*fatn = 0;
+*up = 1;
+if ((fp = fopen(WLOG,"rb")) == NULL) return;
+while (fgets(buffer,100,fp) != NULL)                   
+ {
+ weight   = atof(strtok(buffer," "));
+ bf       = atof(strtok(NULL," "));
+ stardate = atof(strtok(NULL," "));
+ (*n)++;
+ sumweightx += stardate;
+ sumweightxx += stardate * stardate;
+ sumweighty += weight;
+ sumweightxy += stardate * weight;
+ fat = weight * bf / 100;
+ if (fat > 0) 
+  {
+  (*fatn)++;
+   sumfatx += stardate;
+   sumfatxx += stardate * stardate;
+   sumfaty += fat;
+   sumfatxy += stardate * fat;
+  }
+ }
+fclose(fp);
+*weightslope = (sumweightxy - (sumweightx * sumweighty / *n)) / (sumweightxx - (sumweightx * sumweightx / *n));
+if (*fatn > 1) 
+ {
+ *fatslope = (sumfatxy - (sumfatx * sumfaty / *fatn)) / (sumfatxx - (sumfatx * sumfatx / *fatn));
+ if (*fatslope > 0) *up = 0;
+ else if (options.autocal == 2 && *weightslope - *fatslope > 0) *up = 0;
+ *fatslope = (float) (int) (1000 * *fatslope);
+ *fatslope /= 1000;
+ }
+*weightslope = (float) (int) (1000 * *weightslope);
+*weightslope /= 1000;
+}
+
+void write_WLOG(float *weight, float *bf, float *stardate)
+{
+char buffer[128];
+int block, c;
+if (*weight == 0)
+ {
+ rename(WLOG,WLOGold);
+ return;
+ }
+if ((fp = fopen(WLOG,"ab")) == NULL)
+ {
+ printf("Can't open weight log file %s to append.\n",WLOG);
+ abort();
+ }
+sprintf(buffer,"%g %g %g\n",*weight,*bf,*stardate);
+c = strlen(buffer);
+if ((block = fwrite(buffer,c,1,fp)) != 1)
+ {
+ printf("Cannot write to the disk.  Aborting...\n");
+ abort();
+ }
+fclose(fp);
+}
+
 void make_filenames(char *sub)
 {
 strcpy(subuser,sub);
@@ -881,17 +957,20 @@ strcpy(subuser,sub);
  mkdir (nutdir, 0700 );
  sprintf(nutdirsubuser,"%s/%s","NUTDB",subuser);
  mkdir (nutdirsubuser, 0700 );
- sprintf(USDAjoined,"%s/%s","NUTSR21",USDAjoined1);
- sprintf(globalFOOD,"%s/%s","NUTSR21",globalFOOD1);
- sprintf(globalNUT,"%s/%s","NUTSR21",globalNUT1);
- sprintf(globalWEIGHT,"%s/%s","NUTSR21",globalWEIGHT1);
- sprintf(weightlib,"%s/%s","NUTSR21",weightlib1);
+ sprintf(USDAjoined,"%s/%s","NUTSR22",USDAjoined1);
+ sprintf(globalFOOD,"%s/%s","NUTSR22",globalFOOD1);
+ sprintf(globalNUT,"%s/%s","NUTSR22",globalNUT1);
+ sprintf(globalWEIGHT,"%s/%s","NUTSR22",globalWEIGHT1);
+ sprintf(weightlib,"%s/%s","NUTSR22",weightlib1);
+ sprintf(WLOG,"%s/%s","NUTDB",WLOG1);
+ sprintf(WLOGold,"%s/%s","NUTDB",WLOGold1);
  sprintf(localFOOD,"%s/%s/%s","NUTDB",subuser,localFOOD1);
  sprintf(localNUT,"%s/%s/%s","NUTDB",subuser,localNUT1);
  sprintf(localWEIGHT,"%s/%s/%s","NUTDB",subuser,localWEIGHT1);
  sprintf(foodfile,"%s/%s/%s","NUTDB",subuser,foodfile1);
  sprintf(mealfile,"%s/%s/%s","NUTDB",subuser,mealfile1);
  sprintf(mealexpfile,"%s/%s/%s","NUTDB",subuser,mealexpfile1);
+ sprintf(theusualexpfile,"%s/%s/%s","NUTDB",subuser,theusualexpfile1);
  sprintf(theusualfile,"%s/%s/%s","NUTDB",subuser,theusualfile1);
  sprintf(optionsfile,"%s/%s/%s","NUTDB",subuser,optionsfile1);
  sprintf(localOPTIONS,"%s/%s/%s","NUTDB",subuser,localOPTIONS1);
@@ -906,12 +985,15 @@ sprintf(globalFOOD,"%s/%s",FOODDIR,globalFOOD1);
 sprintf(globalNUT,"%s/%s",FOODDIR,globalNUT1);
 sprintf(globalWEIGHT,"%s/%s",FOODDIR,globalWEIGHT1);
 sprintf(weightlib,"%s/%s",FOODDIR,weightlib1);
+sprintf(WLOG,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,WLOG1);
+sprintf(WLOGold,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,WLOGold1);
 sprintf(localFOOD,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localFOOD1);
 sprintf(localNUT,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localNUT1);
 sprintf(localWEIGHT,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localWEIGHT1);
 sprintf(foodfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,foodfile1);
 sprintf(mealfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,mealfile1);
 sprintf(mealexpfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,mealexpfile1);
+sprintf(theusualexpfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,theusualexpfile1);
 sprintf(theusualfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,theusualfile1);
 sprintf(optionsfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,optionsfile1);
 sprintf(localOPTIONS,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localOPTIONS1);
@@ -981,3 +1063,29 @@ if ((block = fwrite(release_string,strlen(release_string)+1,1,fp)) != 1)
  }
 fclose(fp);
 }
+
+void meal_export()
+{                 
+FILE *fp;
+struct meal *meal_ptr = &meal_root;
+if (meal_ptr->next == NULL) return;
+if ((fp = fopen(mealexpfile,"w")) == NULL) return;
+while (meal_ptr->next != NULL)                    
+ {
+ meal_ptr = meal_ptr->next;
+ fprintf(fp,"%s^%d^%d^%f\n",meal_ptr->meal_date,meal_ptr->meal,meal_ptr->ndb_no,
+meal_ptr->grams);
+ }
+fclose(fp);
+meal_ptr = &theusual_root;
+if (meal_ptr->next == NULL) return;
+if ((fp = fopen(theusualexpfile,"w")) == NULL) return;
+while (meal_ptr->next != NULL)                    
+ {
+ meal_ptr = meal_ptr->next;
+ fprintf(fp,"%s^%d^%d^%f\n",meal_ptr->meal_date,meal_ptr->meal,meal_ptr->ndb_no,
+meal_ptr->grams);
+ }
+fclose(fp);
+return;
+}
