@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -50,8 +50,9 @@ LEU_G,LYS_G,MET_G,PHE_G,PRO_G,SER_G,THR_G,TRP_G,TYR_G,VAL_G
 
 int MiscMap[] =
 {
-30,ENERC_KJ,ASH,WATER,CAFFN,THEBRN,ALC,
+33,ENERC_KJ,ASH,WATER,CAFFN,THEBRN,ALC,
 FLD,BETN,CHOLN,FOLAC,FOLFD,FOLDFE,RETOL,VITA_RAE,
+ERGCAL,CHOCAL,VITD_BOTH,
 VITB12_ADDED,VITE_ADDED,
 TOCPHA,TOCPHB,TOCPHG,TOCPHD,CARTA,CARTB,CRYPX,LUT_ZEA,LYCPN,
 CHOLE,PHYSTR,SITSTR,CAMD5,STID7
@@ -137,10 +138,10 @@ DVBase[VITC] = 60;
 DVBase[FASAT] = 20;
 DVBase[CHOLE] = 300;
 DVBase[VITD] = 400;
-DVBase[LA] = 4.44;
-DVBase[AA] = 0.2;
+DVBase[LA] = 9;
+DVBase[AA] = 0.16;
 DVBase[OMEGA6] = DVBase[LA] + DVBase[AA];
-DVBase[ALA] = 2.77;
+DVBase[ALA] = DVBase[LA] / ALA_FACTOR;
 DVBase[EPA] = 0.3;
 DVBase[DHA] = 0.3;
 DVBase[OMEGA3] = DVBase[ALA] + DVBase[EPA] + DVBase[DHA];
@@ -232,6 +233,7 @@ for ( ; ; )
  for (charcount = 0 ; charcount < 60 ; charcount++) substring[charcount] = toupper(substring[charcount]);
  key_encode(substring,key);
  if (strncmp(substring,"THEUSUAL",8) == 0 && usual) return (struct food *) -2;
+ if (strncmp(substring,"PCF ",4) == 0 && usual) return (struct food *) -3;
  header(screentitle);
  food_ptr = &food_root;
  keysize = strlen(key); lines = 0; count = 0;
@@ -245,7 +247,8 @@ for ( ; ; )
   if (substring[0] == '\0') return (struct food *) 0;
   for (charcount = 0 ; charcount < 60 ; charcount++) substring[charcount] = toupper(substring[charcount]);
   key_encode(substring,key);
- if (strncmp(substring,"THEUSUAL",8) == 0 && usual) return (struct food *) -2;
+  if (strncmp(substring,"THEUSUAL",8) == 0 && usual) return (struct food *) -2;
+  if (strncmp(substring,"PCF ",4) == 0 && usual) return (struct food *) -3;
   header(screentitle);
   food_ptr = &food_root;
   keysize = strlen(key); lines = 0; count = 0;
@@ -652,11 +655,7 @@ switch (options.screen)
  h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
  o  = 902 * food_work.nutrient[FAT] * options.fattyacidfactor / food_work.nutrient[ENERC_KCAL] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3];
  n6 = (int) n6hufa(p3,p6,h3,h6,o,food_work.nutrient[ENERC_KCAL]);
- fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
-/*
- if (options.n6hufa == 0 || (options.n6hufa < 90 && options.n6hufa > 15)) fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
- else fprintf(fp,"\n");
-*/
+ fprintf(fp,"Omega-6/3 Balance %2d/%1d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
  break;
  case 2 :
  fprintf(fp,"%-27s","Carbohydrates");
@@ -679,13 +678,13 @@ switch (options.screen)
  break;
  case 3 :
  fprintf(fp,"Miscellaneous Nutrients\n\n");
- for (i = 1; i < 11 ; i++)
+ for (i = 1; i < 12 ; i++)
   {
   food_display_line(fp,ScreenMap[options.screen][i],0,0,0,0);
-  food_display_line(fp,ScreenMap[options.screen][i+10],0,0,0,0);
-  food_display_line(fp,ScreenMap[options.screen][i+20],0,1,0,0);
+  food_display_line(fp,ScreenMap[options.screen][i+11],0,0,0,0);
+  food_display_line(fp,ScreenMap[options.screen][i+22],0,1,0,0);
   }
- fprintf(fp,"\n\n\n");
+ fprintf(fp,"\n\n");
  break;
  case 4 :
  food_display_line(fp,ScreenMap[options.screen][1],0,0,1,0);
@@ -716,16 +715,16 @@ switch (options.screen)
  default :
  if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][1]])) fprintf(fp,"Calories(%4.0f)   %5.0f%%     ",DV[ScreenMap[options.screen][1]],food_work.nutrient[ScreenMap[options.screen][1]]/DV[ScreenMap[options.screen][1]]*100);
  else fprintf(fp,"Calories(%4.0f)    %5s     ",DV[ScreenMap[options.screen][1]],"(nd)");
- if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][14]])) fprintf(fp,"%-14s   %5.0f%%     ",Nutrient[ScreenMap[options.screen][14]],dv_cho());
+ if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][14]])) fprintf(fp,"%-14s   %5.0f%%     ",Nutrient[ScreenMap[options.screen][14]],food_work.nutrient[ScreenMap[options.screen][14]]/DV[ScreenMap[options.screen][14]] *100);
  else fprintf(fp,"%-14s    %5s     ",Nutrient[ScreenMap[options.screen][14]],"(nd)");
- if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][17]])) fprintf(fp,"%-14s   %5.0f%%\n",Nutrient[ScreenMap[options.screen][17]],dv_pro());
+ if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][17]])) fprintf(fp,"%-14s   %5.0f%%\n",Nutrient[ScreenMap[options.screen][17]],food_work.nutrient[ScreenMap[options.screen][17]]/DV[ScreenMap[options.screen][17]] *100);
  else fprintf(fp,"%-14s    %5s\n",Nutrient[ScreenMap[options.screen][17]],"(nd)");
  fprintf(fp,"Carb/Prot/Fat  %8s     ",carbprotfat);
  food_display_line(fp,ScreenMap[options.screen][15],1,0,0,0);
  if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][16]])) fprintf(fp,"%-15s  %5.0f%-1s\n",Nutrient[ScreenMap[options.screen][16]],food_work.nutrient[ScreenMap[options.screen][16]],Unit[ScreenMap[options.screen][16]]);
  else fprintf(fp,"%-15s   %5s\n",Nutrient[ScreenMap[options.screen][16]],"(nd)");
  fprintf(fp,"\n");
- if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][2]])) fprintf(fp,"%-14s   %5.0f%%     ",Nutrient[ScreenMap[options.screen][2]],dv_fat());
+ if (! test_for_negative_zero(&food_work.nutrient[ScreenMap[options.screen][2]])) fprintf(fp,"%-14s   %5.0f%%     ",Nutrient[ScreenMap[options.screen][2]],food_work.nutrient[ScreenMap[options.screen][2]]/DV[ScreenMap[options.screen][2]] *100);
  else fprintf(fp,"%-14s    %5s     ",Nutrient[ScreenMap[options.screen][2]],"(nd)");
  food_display_line(fp,ScreenMap[options.screen][18],1,0,0,0);
  food_display_line(fp,ScreenMap[options.screen][30],1,1,0,0);
@@ -767,11 +766,7 @@ switch (options.screen)
  h6 = 902 * food_work.nutrient[LONG6] / food_work.nutrient[ENERC_KCAL];
  o  = 902 * food_work.nutrient[FAT] * options.fattyacidfactor / food_work.nutrient[ENERC_KCAL] - food_work.nutrient[SHORT6] - food_work.nutrient[LONG6] - food_work.nutrient[SHORT3] - food_work.nutrient[LONG3];
  n6 = (int) n6hufa(p3,p6,h3,h6,o,food_work.nutrient[ENERC_KCAL]);               
-fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
-/*
- if (options.n6hufa == 0 || (options.n6hufa < 90 && options.n6hufa > 15)) fprintf(fp,"Omega-6/3 Balance %2d/%2d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
- else fprintf(fp,"\n");
-*/
+fprintf(fp,"Omega-6/3 Balance %2d/%1d\n",n6 == 0 ? 0 : n6,n6 == 0 ? 0 : 100-n6);
  break;
  }
 }
@@ -933,7 +928,7 @@ m->next = po;
 void compute_derived_fields(struct food *food_ptr)
 {
 float ratio, realcal, alcCalFactor = 6.93;;
-food_ptr->nutrient[VITE] = 1.5 * food_ptr->nutrient[TOCPHA];
+food_ptr->nutrient[VITE] = (food_ptr->nutrient[VITE_ADDED] / 0.45) + ((food_ptr->nutrient[TOCPHA] - food_ptr->nutrient[VITE_ADDED]) / 0.67);
 food_ptr->nutrient[LA] = food_ptr->nutrient[F18D2CN6] > 0 ? food_ptr->nutrient[F18D2CN6] : food_ptr->nutrient[F18D2] - food_ptr->nutrient[F18D2T] - food_ptr->nutrient[F18D2TT] - food_ptr->nutrient[F18D2I] - food_ptr->nutrient[F18D2CLA];
 if (food_ptr->nutrient[LA] == 0 && test_for_negative_zero(&food_ptr->nutrient[F18D2])) food_ptr->nutrient[LA] = NoData;
 if (food_ptr->nutrient[LA] < 0) food_ptr->nutrient[LA] = 0;
@@ -986,34 +981,6 @@ food_ptr->nutrient[CHO_NONFIB] = food_ptr->nutrient[CHOCDF] - food_ptr->nutrient
 if (food_ptr->nutrient[CHO_NONFIB] < 0) food_ptr->nutrient[CHO_NONFIB] = 0;
 }
 
-float dv_fat()
-{
-float targetpct, totalcal, totaldv, imaginarydv, diff;
-targetpct = food_work.nutrient[ENERC_KCAL] / DV[ENERC_KCAL];
-if (options.pccarb == 0 && options.pcprotein == 0)
- {
- totalcal = food_work.nutrient[PROCNT] * options.protcalpergm + food_work.nutrient[CHOCDF] * options.carbcalpergm + food_work.nutrient[FAT] * options.fatcalpergm;
- totaldv = DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm + DV[FAT] * options.fatcalpergm;
- imaginarydv = totalcal / targetpct;
- diff = (totaldv - imaginarydv) / options.fatcalpergm;
- if (DV[FAT] > diff) return food_work.nutrient[FAT] / (DV[FAT] - diff) * 100;
- else return food_work.nutrient[FAT] / DV[FAT] * 100;
- }
-else return diff = 100 * food_work.nutrient[FAT_KCAL] / (DV[ENERC_KCAL] * (1 - (options.pccarb > 0 ? options.pccarb / 100 : DV[CHOCDF] * options.carbcalpergm / DV[ENERC_KCAL]) - (options.pcprotein > 0 ? options.pcprotein / 100 : DV[PROCNT] * options.protcalpergm / DV[ENERC_KCAL])));
-}
-
-float dv_cho()
-{
-if (options.pccarb > 0) return food_work.nutrient[CHO_KCAL] / DV[ENERC_KCAL] / options.pccarb * 10000;
-else return food_work.nutrient[CHOCDF] / DV[CHOCDF] * 100;
-}
-
-float dv_pro()
-{
-if (options.pcprotein > 0) return food_work.nutrient[PROT_KCAL] / DV[ENERC_KCAL] / options.pcprotein * 10000;
-else return food_work.nutrient[PROCNT] / DV[PROCNT] * 100;
-}
-
 char *format_serving(char *buffer, float *ratio, struct food *food_ptr)
 {
 sprintf(buffer,"%1.3g",food_ptr->qty * *ratio);
@@ -1033,7 +1000,7 @@ float answer;
 printf("%f %f %f %f %f\n",p3,p6,h3,h6,o);
 exit(0);
 */  
-if (p3 == 0 && p6 == 0 && h3 == 0 && h6 == 0 && o == 0) return 0;
+if (p3 == 0 && p6 == 0 && h3 == 0 && h6 == 0) return 0;
 if (c == 0) return 0;
 answer = 100 / (1 + pc6/p6 * (1 + p3/pc3 + h3/hi3 + o/co + p6/ks)) + 100 / (1 + hc6/h6 * (1 + h3/hc3));
 if (answer <= 90 && answer >= 15) return answer;
