@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -88,9 +88,6 @@ void order_new_recipe(void);
 void modify_recipe_food(int, char *);
 void modify_label_food(int, char *);
 void compute_derived_fields(struct food *);
-float dv_fat(void);
-float dv_cho(void);
-float dv_pro(void);
 char *format_serving(char *, float *, struct food *);
 float n6hufa(float, float, float, float, float, float);
 
