@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 
 struct opt options;
 
-static float DefaultTarget = 90, DefaultEPADHA = 0.7;
+static float DefaultTarget = 50, DefaultEPADHA = 2.2;
 
 void initialize_options()
 {
@@ -66,11 +66,16 @@ float buf = 0;
 int choice;
 options.abnuts[FAMS] = 0;
 header("NUT:  Set Personal Calorie Level");
-printf("\n  Calorie level is set to %0.0f.\n\n",DV[ENERC_KCAL]);
+if (options.autocal == 0 ) printf("\n  Calorie level is set to %0.0f.\n\n",DV[ENERC_KCAL]);
+else printf("\n  Calorie level is set to %0.0f.  Option is #%d.\n\n",DV[ENERC_KCAL],options.autocal + 2);
 printf("\n  1.  I will type a new calorie level.\n");
 printf("\n  2.  I want to return to the program default of 2000.\n");
 printf("\n  3.  I want NUT to automatically use the average calories from all my meals.\n");
-spacer(9);
+printf("\n  4.  When I make a daily \"Weight Log Regression\" entry, make a small calorie\n");
+printf("      adjustment to promote loss of fat mass without loss of lean mass.\n");
+printf("\n  5.  When I make a daily \"Weight Log Regression\" entry, make a small calorie\n");
+printf("      adjustment to promote gain of lean mass without gain of fat mass.\n");
+spacer(15);
 printf("\nEnter your choice (just <enter> to retain current setting):  ");
 choice = get_int();
 switch (choice)
@@ -86,7 +91,7 @@ switch (choice)
    options.locknuts[ENERC_KCAL] = 1;
    options.abnuts[ENERC_KCAL] = buf;
    }
-  options.abnuts[FAT] = 0;
+  if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
   options.abnuts[FAMS] = 0;
   options.autocal = 0;
   break;
@@ -99,10 +104,26 @@ switch (choice)
   options.abnuts[FAMS] = 0;
   options.autocal = 1;
   break;
+ case 4 :
+  options.locknuts[ENERC_KCAL] = 1;
+  options.locknuts[FAT] = 0;
+  options.abnuts[FAT] = 0;
+  options.locknuts[FAMS] = 0;
+  options.abnuts[FAMS] = 0;
+  options.autocal = 2;
+  break;
+ case 5 :
+  options.locknuts[ENERC_KCAL] = 1;
+  options.locknuts[FAT] = 0;
+  options.abnuts[FAT] = 0;
+  options.locknuts[FAMS] = 0;
+  options.abnuts[FAMS] = 0;
+  options.autocal = 3;
+  break;
  case 2 :
   options.locknuts[ENERC_KCAL] = 0;
   options.abnuts[ENERC_KCAL] = 0;
-  options.abnuts[FAT] = 0;
+  if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
   options.abnuts[FAMS] = 0;
   options.autocal = 0;
   break;
@@ -185,7 +206,7 @@ void efa_method()
 {
 if (options.locknuts[FAPU] == 1)
  {
- options.abnuts[FAT] = 0;
+ if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
  options.abnuts[FAMS] = 0;
  options.abnuts[FAPU] = 0; options.locknuts[FAPU] = 0;
  options.abnuts[OMEGA6] = 0; options.locknuts[OMEGA6] = 0;
@@ -227,8 +248,7 @@ if ( options.pcprotein > 0 )
  options.abnuts[PROCNT] = 0;
  options.locknuts[PROCNT] = 1;
  }
-options.abnuts[FAT] = 0;
-options.locknuts[FAT] = 0;
+if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.locknuts[FAMS] = 0;
 auto_cal(&DV[ENERC_KCAL],0);
@@ -251,8 +271,7 @@ if ( options.pccarb <= 0 || (options.pcprotein + options.pccarb) > 90 )
  options.locknuts[CHOCDF] = 0;
  }
 if ( options.pccarb > 0 ) options.abnuts[CHOCDF] = 0;
-options.abnuts[FAT] = 0;
-options.locknuts[FAT] = 0;
+if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.locknuts[FAMS] = 0;
 auto_cal(&DV[ENERC_KCAL],0);
@@ -275,7 +294,7 @@ if ( options.pcsatfat <= 0  || options.pcsatfat > 90 )
  options.locknuts[FASAT] = 0;
  options.abnuts[FASAT] = 0;
  }
-options.abnuts[FAT] = 0;
+if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.locknuts[FAMS] = 0;
 auto_cal(&DV[ENERC_KCAL],0);
@@ -301,8 +320,7 @@ if ( options.abnuts[PROCNT] > 0 )
  options.pcprotein = 0;
  options.locknuts[PROCNT] = 1;
  }
-options.abnuts[FAT] = 0;
-options.locknuts[FAT] = 0;
+if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.locknuts[FAMS] = 0;
 auto_cal(&DV[ENERC_KCAL],0);
@@ -314,19 +332,18 @@ void carb_absolute()
 {
 char buf[128];
 header("NUT:  Carbohydrate Absolute Amount");
-spacer(0);
-printf("\nEnter grams of carbohydrate (just <enter> for default):  ");
+spacer(1);
+printf("\nEnter grams of carbohydrate, or a negative value to set grams of non-fiber carb");
+printf("\nindependent of fiber (just <enter> for default):  ");
 get_string(buf,127);
 options.abnuts[CHOCDF] = atof(buf);
 options.locknuts[CHOCDF] = 0;
-if ( options.abnuts[CHOCDF] <= 0 ) options.abnuts[CHOCDF] = 0;
-if ( options.abnuts[CHOCDF] > 0 )
+if ( options.abnuts[CHOCDF] != 0 )
  {
  options.pccarb = 0;
  options.locknuts[CHOCDF] = 1;
  }
-options.abnuts[FAT] = 0;
-options.locknuts[FAT] = 0;
+if (!options.locknuts[FAT]) options.abnuts[FAT] = 0;
 options.abnuts[FAMS] = 0;
 options.locknuts[FAMS] = 0;
 auto_cal(&DV[ENERC_KCAL],0);
@@ -379,7 +396,7 @@ void auto_cal(float *bufptr, int analflag)
 {
 float buf = *bufptr, temp = 0;
 int i;
-if (options.autocal) buf = average_cals();
+if (options.autocal == 1) buf = average_cals();
 if (analflag)
  {
  if (food_work.nutrient[PROT_KCAL] > 0 && food_work.nutrient[PROCNT] > 0) options.protcalpergm = food_work.nutrient[PROT_KCAL] / food_work.nutrient[PROCNT];
@@ -431,6 +448,7 @@ if (options.pcprotein > 0) DV[PROCNT] = options.pcprotein / 100 * DV[ENERC_KCAL]
 if (options.abnuts[PROCNT] > 0) DV[PROCNT] = options.abnuts[PROCNT];
 if (options.pccarb > 0) DV[CHOCDF] = options.pccarb / 100 * DV[ENERC_KCAL] / options.carbcalpergm;
 if (options.abnuts[CHOCDF] > 0) DV[CHOCDF] = options.abnuts[CHOCDF];
+if (options.abnuts[CHOCDF] < 0) DV[CHOCDF] = DV[FIBTG] + -1 * options.abnuts[CHOCDF];
 if (DV[PROCNT] != DVBase[PROCNT] || DV[CHOCDF] != DVBase[CHOCDF])
  {
  temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
@@ -470,8 +488,8 @@ if (options.pcsatfat > 0)
  DV[FASAT] = DVBase[FASAT] * buf * options.pcsatfat * .1;
  DV[FAMS] = temp - DV[FASAT];
  }
-if (options.abnuts[CHOCDF] > 0 && options.abnuts[PROCNT] > 0 && options.abnuts[FAT] > 0) DV[FAT] = options.abnuts[FAT];
-if (options.abnuts[CHOCDF] > 0 && options.abnuts[PROCNT] > 0 && options.abnuts[FAMS] > 0) DV[FAMS] = options.abnuts[FAMS];
+if (options.abnuts[CHOCDF] != 0 && options.abnuts[PROCNT] > 0 && options.abnuts[FAT] > 0) DV[FAT] = options.abnuts[FAT];
+if (options.abnuts[CHOCDF] != 0 && options.abnuts[PROCNT] > 0 && options.abnuts[FAMS] > 0) DV[FAMS] = options.abnuts[FAMS];
 if (options.abnuts[CHOLE] > 0) DV[CHOLE] = options.abnuts[CHOLE]; 
 if (options.abnuts[VITA_IU] > 0) DV[VITA_IU] = options.abnuts[VITA_IU]; 
 if (options.abnuts[THIA] > 0) DV[THIA] = options.abnuts[THIA]; 
@@ -497,7 +515,7 @@ if (options.abnuts[NA] > 0) DV[NA] = options.abnuts[NA];
 if (options.abnuts[ZN] > 0) DV[ZN] = options.abnuts[ZN]; 
 if (! options.abnuts[CHO_NONFIB]) DV[CHO_NONFIB] = DV[CHOCDF] - DV[FIBTG] < 0 ? 0 : DV[CHOCDF] - DV[FIBTG];
 else DV[CHO_NONFIB] = options.abnuts[CHO_NONFIB];
-if ( options.pcsatfat > 0 || options.pcprotein > 0 || options.pccarb > 0 || options.abnuts[PROCNT] > 0 || options.abnuts[CHOCDF] > 0 || options.abnuts[FIBTG] > 0 || options.abnuts[VITE]) options.custom = 1;
+if ( options.pcsatfat > 0 || options.pcprotein > 0 || options.pccarb > 0 || options.abnuts[PROCNT] > 0 || options.abnuts[CHOCDF] != 0 || options.abnuts[FIBTG] > 0 || options.abnuts[VITE]) options.custom = 1;
 else options.custom = 0;
 write_OPTIONS();
 }
@@ -724,3 +742,69 @@ else
   }
  }
 }
+
+void weight_log()
+{
+char newentry[128];
+int n, nfat, up, justmadenewentry = 0;
+float weightslope, fatslope;
+float weight, bf, stardate;
+time_t t;
+
+while (1)
+ {
+ header("NUT:  Weight Log Regression");
+ read_WLOG(&n,&nfat,&up,&weightslope,&fatslope);
+ if (justmadenewentry && options.autocal > 1 && nfat > 1)
+  {
+  if (up) options.abnuts[ENERC_KCAL] += 20;
+  else options.abnuts[ENERC_KCAL] -= 20;
+  auto_cal(&options.abnuts[ENERC_KCAL],0);
+  }
+ justmadenewentry = 0;
+ printf("\n\n");
+ printf("                           data points:   %6d\n",n);
+ printf("\n\n");
+ printf("  Based on the trend\n");
+ printf("  of data points so far...\n\n\n");
+ if (n < 2) printf("         Predicted daily weight change:        ?\n\n");
+ else printf("         Predicted daily weight change:   %+10.3f\n\n",weightslope);
+ if (nfat < 2)
+  {
+  printf("      Predicted daily lean mass change:        ?\n\n");
+  printf("       Predicted daily fat mass change:        ?\n\n");
+  }
+ else
+  {
+  printf("      Predicted daily lean mass change:   %+10.3f\n\n",weightslope-fatslope);
+  printf("       Predicted daily fat mass change:   %+10.3f\n\n",fatslope);
+  }
+ spacer(14);
+ if (n > 0) printf("Type daily weight and body fat %% (! to clear log, <enter> to quit):  ");
+ else printf("Type daily weight and body fat %% (<enter> to quit):  ");
+ get_string(newentry,127);
+ if (strlen(newentry) == 0 || newentry[0] == ' ') return;
+ if (strchr(newentry,'!') != NULL)
+  {
+  weight = 0;
+  if (n > 0) write_WLOG(&weight,&bf,&stardate);
+  }
+ else
+  {
+  time(&t);
+  if (strchr(newentry,' ') == NULL || newentry[strlen(newentry)-1] == ' ')
+   {
+   weight   = atof(strtok(newentry," "));
+   bf = 0;
+   }
+  else
+   {
+   weight   = atof(strtok(newentry," "));
+   bf       = atof(strtok(NULL," "));
+   justmadenewentry = 1;
+   }
+  stardate = ((float) t / 86400) - 14486;
+  if (weight > 0) write_WLOG(&weight,&bf,&stardate);
+  }
+ }
+}
