@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,18 +29,19 @@ struct opt
  {
  int delopt;
  int defanal;
+ int defanalanal;
+ int defanalrec;
  int screen;
  int custom;
  float pcprotein;
  float pccarb;
  float pcsatfat;
- float fatprotratio;
  float carbcalpergm;
  float protcalpergm;
  float fatcalpergm;
  float fattyacidfactor;
  float n6hufa;
- int n6hufaspec;
+ float epadhamax;
  int next_recipe;
  int locknuts[NUTRIENT_COUNT];
  float abnuts[NUTRIENT_COUNT];
@@ -50,6 +51,8 @@ struct opt
  struct meal *temp_meal_root;
  };
 
+#define ALA_FACTOR    6
+
 #define DELOPT        1000 
 #define DEFANAL       1001
 #define SCREEN        1002
@@ -57,7 +60,6 @@ struct opt
 #define PCPROTEIN     1004
 #define PCCARB        1005
 #define PCSATFAT      1006
-#define FATPROTRATIO  1007
 #define NEXT_RECIPE   1008
 #define MEALSPERDAY   1009
 #define GRAMS         1010 
@@ -67,7 +69,9 @@ struct opt
 #define FATCALPERGM   1014
 #define FATTYACIDFACTOR 1015
 #define N6HUFA        1016
-#define N6HUFASPEC    1017
+#define EPADHAMAX     1018
+#define DEFANALANAL   1019
+#define DEFANALREC    1020
 
 #define OPT_CHO_NONFIB 2000
 #define OPT_LA         2001
@@ -84,9 +88,9 @@ extern int mealdb_mealsperday;
 
 void initialize_options(void);
 void personal_cal(void);
+void efa_options(void);
 void efa_method(void);
 void protein_percent(void);
-void fatprot_ratio(void);
 void carb_percent(void);
 void satfat_percent(void);
 void protein_absolute(void);
@@ -99,7 +103,7 @@ void screen_previous(void);
 void get_cals(float *);
 void new_nut_levels(void);
 void restore_defaults(int);
-void set_defanal(void);
 void efa_dynamics();
+void weight_log();
 
 #endif
