@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2008 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include "food.h"
 #include "options.h"
 #include "util.h"
+#include "db.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -81,6 +82,7 @@ fprintf(fp,"\n");
 food_display(fp);
 clear_work();
 fclose(fp);
+/* meal_export(); */
 header("NUT:  Print Menus from Meal Database");
 spacer(0);
 printf("\nMenus printed to \"menus.txt\".  Press <enter> to continue..."); 
