@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2009 by Jim Jozwiak.
+    Copyright (C) 1996-2010 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -285,6 +285,6 @@ signsense = f->sign;
 int test_for_negative_zero(float *value) {
 wjl_ieee754_float_t *f = (wjl_ieee754_float_t *)value;
 if (*value != 0) return 0;
-if (f->sign != signsense) return 0;
+else if (f->sign != signsense) return 0;
 else return 1;
 }
